@@ -2,10 +2,9 @@ use v5.32;
 use warnings;
 use Object::Pad 0.73;
 
-class Archive::SCS::GameDir 1.08;
+class Archive::SCS::GameDir 1.09;
 
-use builtin 'trim';
-no warnings 'experimental::builtin';
+use builtin::compat 'trim';
 
 use Archive::SCS;
 use Carp 'croak';
